# Canvas

`canvas_ux` ties together a collection of interactive visualizations that let you explore data. It is designed to be extensible and thus can integrate different [components](../widgets). If you are interested in creating you own component, take a look at our [cookiecutter](../widget-cookiecutter/).

## Installation

```bash
pip install canvas_ux
```

## Usage

To learn how to use Canvas, see the [documentation](https://betterwithdata.github.io/ml-canvas/).

## Development

To learn about how to build Canvas from source and how to contribute to the framework, please look at [CONTRIBUTING.md](../CONTRIBUTING.md) and the [development documentation](https://betterwithdata.github.io/ml-canvas/contributing.html).
